#include "examples.h"

const int DIMENSIONS = 2;    // number of dimensions
const int ITERATIONS = 15;   // number of iterations
                             // keep ITERATIONS <= 18 for gnuplot to work properly
                             // keep ITERATIONS <= 20 for memory allocation

const double BOX_K = 10.0;    // size of initial box [-BOX_K, BOX_K]
const double MAX_TIME = 2.0; // maximum time value

const int doLog = 0;         // 0 means no log files; 1 means create log files
const int doPlot = 1;        // 0 means no log files; 1 means create log files

const int dim1 = 0; // first dimension for 3d plot, usually 0
const int dim2 = 1; // second dimension for 3d plot, usually 1
const double MIN_RES = 0.01; // small cubes are not visible in gnuplot

char *equationName = "x' = y|sin(1/y)| + 1, y' = x|cos(1/x)| - 1; x(0) = 0, y(0) = 0";

void computeDerivativeValue(int dim, mpfi_t v, mpfi_t x[DIMENSIONS]) {
	mpfr_t c_;
	mpfr_init(c_);
	mpfr_set_d(c_, 1, GMP_RNDN);

	switch (dim) {
	case 0:
//printf("x1="); mpfi_out_str(stdout, 10, 0, x[1]); printf(" ");
		mpfi_d_div(v, 1.0, x[1]);
//printf("1/x1="); mpfi_out_str(stdout, 10, 0, v); printf(" ");
		mpfi_sin(v, v);
//printf("sin="); mpfi_out_str(stdout, 10, 0, v); printf("\n");
		mpfi_abs(v, v);
		mpfi_mul(v, v, x[1]);
		mpfi_add_fr(v, v, c_);
		break;
	case 1:
		mpfi_d_div(v, 1.0, x[0]);
		mpfi_cos(v, v);
		mpfi_abs(v, v);
		mpfi_mul(v, v, x[0]);
		mpfi_sub_fr(v, v, c_);
		break;
	}

	mpfr_clear(c_);
}
